@@ -1,7 +1,7 @@
 import uuid
 from datetime import datetime
 from enum import Enum
-from typing import Any, Type, Dict, List, Optional, KeysView
+from typing import Any, Type, Dict, List, Optional, KeysView, Set
 from pydantic import BaseModel
 import zstandard
 
@@ -13,6 +13,15 @@ class Kind(str, Enum):
     Describe = "DESC"
 
 
+class Log(BaseModel):
+    name: str
+    version: str
+    updated: Set[str]
+    received: datetime = datetime.now()
+    processed: Optional[datetime] = None
+    elapsed: Optional[float] = None
+
+
 class Message(BaseModel):
     """:class:`Message` is a container for data in pipeline. Data will be wrapped in
     :class:`Message` in order to pass through a pipeline constructed with this library.
@@ -29,7 +38,7 @@ class Message(BaseModel):
     kind: Optional[Kind] = Kind.Message
     id: str = uuid.uuid1()
     created: datetime = datetime.now()
-    logs: List[BaseModel] = []
+    logs: List[Log] = []
     content: Dict[str, Any] = {}
 
     @classmethod
